@@ -654,6 +654,9 @@ class CalcDataFrame(object):
         all_data = pd.merge_asof(left=fund_ret[fund_colunm], right=market_ret[market_colunm], left_index=True,
                                  right_index=True,
                                  direction=direction)
+        if fund_colunm == market_colunm:
+            fund_colunm = fund_colunm + '_x'
+            market_colunm = fund_colunm + '_y'
         cal_data = fund_ret[start_date:end_date]
         if isinstance(period, str):
             period = [period]
